==> rdg-corp-sh-games-1.1.0-810417.zip: README.md <==
# RDG Corp / SH Games Plugin for WordPress

Tags: sh games, sh, game
Requires at least: 6.0
Tested up to: 6.0
Requires PHP: 8.1
Stable tag: 1.1.0
License: GPLv3 or later
License URI: http://www.gnu.org/licenses/gpl-3.0.html

# Changelog
-   1.1.0 (2024-03-05)
    * DEV-103-sh-games-plugin-complete
        - Versions for simple and complete sh game are integrated.
-   1.0.18 (2023-10-16)
    * DEV-103-sh-games-plugin-simple-fix-slug
        - cpt slug defined in environment constants.
-   1.0.17 (2023-10-11)
    * resease/1.0.12
        - The origin of the date for the posts is modified.
-   1.0.16 (2023-10-10)
    * resease/1.0.12
        - Game menu name updated.
-   1.0.15 (2023-10-09)
    * resease/1.0.12
        - Fixed redis data reading and writing.
-   1.0.14 (2023-10-06)
    * resease/1.0.12
        - Image validation is fixed.
        - Date selection in request is fixed.
-   1.0.13 (2023-10-05)
    * resease/1.0.12
        - Title generation fixed.
        - CPT label name fix.
-   1.0.12 (2023-10-05)
    * DEV-103-sh-games-plugin-simple-fix
        - URL generation fixed.
-   1.0.11 (2023-10-04)
    * DEV-103-sh-games-plugin-simple
        - Simple version of the sh-games plugin is finalized.
-   1.0.10 (2023-08-24)
    * DEV-103-sh-games-plugin-request
        - It is allowed to assign game parts by sports.
-   1.0.9 (2023-08-11)
    * DEV-103-sh-games-plugin-request
        - Assignment of parents to categories is allowed.
-   1.0.8 (2023-08-11)
    * DEV-103-sh-games-plugin-request
        - Cleaned up query.
        - Validation adjustments were made.
-   1.0.7 (2023-08-10)
    * DEV-103-sh-games-plugin-request
        - CPT customization is allowed.
-   1.0.6 (2023-08-10)
    * DEV-103-sh-games-plugin-request
        - Multiple sports filter applied.
-   1.0.5 (2023-08-08)
    * DEV-103-sh-games-plugin
        - Form Automatic Games changed.
-   1.0.4 (2023-08-08)
    * DEV-103-sh-games-plugin
        - Form priority changed.
-   1.0.3 (2023-08-08)
    * DEV-103-sh-games-plugin
        - Update form key.
-   1.0.2 (2023-08-07)
    * DEV-103-sh-games-plugin
        - Create composer file.
-   1.0.1 (2023-08-07)
    * DEV-103-sh-games-plugin
        - Most of the features have been implemented.
        - Missing the final api and remove the slug from the CTP.
-   1.0.0 (2023-07-26)
    * DEV-103-sh-games-plugin
        - The base of the sh games plugin was initialized.

==> rdg-corp-sh-games-1.1.4-216980.zip: README.md <==
# RDG Corp / SH Games Plugin for WordPress

Tags: sh games, sh, game
Requires at least: 6.0
Tested up to: 6.0
Requires PHP: 8.1
Stable tag: 1.1.4
License: GPLv3 or later
License URI: http://www.gnu.org/licenses/gpl-3.0.html

# Changelog
-   1.1.4 (2024-03-12)
    * DEV-103-sh-games-plugin-complete
        - Added featured image and other changes.
-   1.1.3 (2024-03-12)
    * DEV-103-sh-games-plugin-complete
        - Title shadow color is customized.
-   1.1.2 (2024-03-12)
    * DEV-103-sh-games-plugin-complete
        - The implementation of SH Mapping is validated.
-   1.1.1 (2024-03-11)
    * DEV-103-sh-games-plugin-complete
        - The requested changes have been completed.
-   1.1.0 (2024-03-05)
    * DEV-103-sh-games-plugin-complete
        - Versions for simple and complete sh game are integrated.
-   1.0.18 (2023-10-16)
    * DEV-103-sh-games-plugin-simple-fix-slug
        - cpt slug defined in environment constants.
-   1.0.17 (2023-10-11)
    * resease/1.0.12
        - The origin of the date for the posts is modified.
-   1.0.16 (2023-10-10)
    * resease/1.0.12
        - Game menu name updated.
-   1.0.15 (2023-10-09)
    * resease/1.0.12
        - Fixed redis data reading and writing.
-   1.0.14 (2023-10-06)
    * resease/1.0.12
        - Image validation is fixed.
        - Date selection in request is fixed.
-   1.0.13 (2023-10-05)
    * resease/1.0.12
        - Title generation fixed.
        - CPT label name fix.
-   1.0.12 (2023-10-05)
    * DEV-103-sh-games-plugin-simple-fix
        - URL generation fixed.
-   1.0.11 (2023-10-04)
    * DEV-103-sh-games-plugin-simple
        - Simple version of the sh-games plugin is finalized.
-   1.0.10 (2023-08-24)
    * DEV-103-sh-games-plugin-request
        - It is allowed to assign game parts by sports.
-   1.0.9 (2023-08-11)
    * DEV-103-sh-games-plugin-request
        - Assignment of parents to categories is allowed.
-   1.0.8 (2023-08-11)
    * DEV-103-sh-games-plugin-request
        - Cleaned up query.
        - Validation adjustments were made.
-   1.0.7 (2023-08-10)
    * DEV-103-sh-games-plugin-request
        - CPT customization is allowed.
-   1.0.6 (2023-08-10)
    * DEV-103-sh-games-plugin-request
        - Multiple sports filter applied.
-   1.0.5 (2023-08-08)
    * DEV-103-sh-games-plugin
        - Form Automatic Games changed.
-   1.0.4 (2023-08-08)
    * DEV-103-sh-games-plugin
        - Form priority changed.
-   1.0.3 (2023-08-08)
    * DEV-103-sh-games-plugin
        - Update form key.
-   1.0.2 (2023-08-07)
    * DEV-103-sh-games-plugin
        - Create composer file.
-   1.0.1 (2023-08-07)
    * DEV-103-sh-games-plugin
        - Most of the features have been implemented.
        - Missing the final api and remove the slug from the CTP.
-   1.0.0 (2023-07-26)
    * DEV-103-sh-games-plugin
        - The base of the sh games plugin was initialized.
